.. -*- rst -*-

==================
Sense HAT Emulator
==================

This package emulates the Raspberry Pi `Sense HAT`_. An interactive GTK
application is provided to permit manipulation of the emulated sensors, along
with command line utilities for recording and playing back sensor readings from
an actual HAT.

Links
=====

* The library code is licensed under the `LGPL version 2.1`_ or above, while
  the applications ``sense_emu_gui``, ``sense_rec``, ``sense_play``, and
  ``sense_csv`` are licensed under the `GPL version 2.0`_ or above.
* The `source code`_ can be obtained from GitHub, which also hosts the `bug
  tracker`_
* The `documentation`_ (which includes installation, API reference and example
  scripts) can be read on ReadTheDocs
* Packages can be downloaded from `PyPI`_, but reading the installation
  instructions is likely to be more useful

.. _Sense HAT: https://www.raspberrypi.org/products/sense-hat/
.. _source code: https://github.com/RPi-Distro/python-sense-emu
.. _bug tracker: https://github.com/RPi-Distro/python-sense-emu/issues
.. _documentation: https://sense-emu.readthedocs.io
.. _PyPI: https://pypi.python.org/pypi/sense_emu/
.. _LGPL version 2.1: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
.. _GPL version 2.0: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html

